#!/bin/sh


echo_n="`which echo` -n"

names=( git curl wget cc gcc clang make aclocal patch ssh-keygen ssh scp expect java )

for name in ${names[@]}
do
	$echo_n "check $name... "
	if [ -z `which $name` ]; then
		echo "\n\033[1;31mERROR! $name not found.\033[m"
		exit
	fi
	echo "ok."
done


echo "\ncheck opensn0w..."

if [ ! -e "${PWD}/opensn0w_build/bin/opensn0w_cli" -o ! -e "${PWD}/opensn0w_build/lib/libsn0wcore.1.0.dylib" ]; then
	if [ -e "${PWD}/opensn0w" ]; then
		echo "opensn0w found but not compiled yet."
		pushd ${PWD}/opensn0w
		#git pull
		#patch -p1 < ../opensn0w3.diff
	else
		echo "opensn0w not found"
		git clone https://github.com/winocm/opensn0w ${PWD}/opensn0w
		pushd ${PWD}/opensn0w
		patch -p1 < ../opensn0w3.diff
	fi
	
	echo "compile opensn0w..."
	./autogen.sh
	./configure --prefix=${PWD}_build
	make
	make install

	popd
fi

if [ ! -e "${PWD}/opensn0w_build/bin/opensn0w_cli" -o ! -e "${PWD}/opensn0w_build/lib/libsn0wcore.1.0.dylib" ]; then
	echo "\n\033[1;31mERROR! fail to initialize opensn0w. Aborted!\033[m"
	exit
fi


echo "\ncheck SSH bundle..."

if [ ! -e "${PWD}/SSH2_bundle.tgz" ]; then
	echo "download SSH2_bundle.tgz"
	SSH=`curl -s "https://sites.google.com/a/iphone-dev.com/files/home/SSH2_bundle.tgz?attredirects=0" | grep "here" | sed 's/.*<A HREF=\"//;s/\">here<\/A>.*//'`

	curl -o SSH2_bundle.tgz "$SSH"
fi


echo "\ncheck SSH ramdisk..."

if [ ! -e "${PWD}/ssh_rd_rev04b.jar" ]; then
	echo "donwload ssh_rd_rev04b.jar"
	RAMDISK=`curl -s "https://sites.google.com/site/msftguy/file/ssh_rd_rev04b.jar?attredirects=0" | grep "here" | sed 's/.*<A HREF=\"//;s/\">here<\/A>.*//'`
	
	curl -o ssh_rd_rev04b.jar "$RAMDISK"
fi


echo "\ncheck binaries..."

if [ ! -e "${PWD}/SSH2_bundle/bin/bzip2" -o ! -e "${PWD}/SSH2_bundle/bin/gzip" -o ! -e "${PWD}/SSH2_bundle/bin/tar" ]; then
	mkdir -p SSH2_bundle
	tar zxvfp SSH2_bundle.tgz -C SSH2_bundle bin/bzip2 bin/gzip bin/tar
fi


echo "\ncheck apt7-lib package..."

if [ ! -e "${PWD}/apt7-lib_0.7.25.3-9_iphoneos-arm.deb" ]; then
	echo "download apt7-lib_0.7.25.3-9_iphoneos-arm.deb"
	wget http://apt.saurik.com/debs/apt7-lib_0.7.25.3-9_iphoneos-arm.deb
fi


open ssh_rd_rev04b.jar


echo "\033[34m"
echo ""
echo "Stage 0 is complete."
echo ""
echo "You should make your device in \033[1;31mDFU\033[m\033[34m mode."
echo "\033[m"

